# coding: utf-8

"""
    Mentortools AI API

    Mentortools service for ai interactions

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class ResponseChunkType(str, Enum):
    """
    Type of the streamed response chunk.
    """

    """
    allowed enum values
    """
    TEXT = 'text'
    USAGE = 'usage'
    ASYNC_HANDLED = 'async_handled'
    CHAT_NAME = 'chat_name'

    @classmethod
    def from_json(cls, json_str: str) -> ResponseChunkType:
        """Create an instance of ResponseChunkType from a JSON string"""
        return ResponseChunkType(json.loads(json_str))


